@@ -276,6 +276,8 @@ class Component:
         :param str, name: name of the component
         :param str, path: path to save the component in. The last part of the path must be the name of the component
         """
+        warnings.warn('This class is depcreciated and will be removed soon',
+                      DeprecationWarning)
         self._name = name
         self._path = path
         self._parent = None  # parent Component this component belongs to; can be set to None if it is the first
@@ -400,6 +402,8 @@ class Folder(Component):
         :param str, folder_path: path to save the folder on disk
         :param str, folder_name: Should be the same as the last part of the folder path
         """
+        warnings.warn('This class is depcreciated and will be removed soon',
+                      DeprecationWarning)
         super().__init__(
             name=folder_name,
             path=folder_path
@@ -439,7 +443,7 @@ class Folder(Component):
         :return:
         """
         self.children.add(component)
-        component.parent = self
+        # component.parent = self
 
     def remove_and_delete_component(self,
                                     component: Component,
@@ -475,7 +479,7 @@ class Folder(Component):
                 folder_name=sub_folder_name,
                 folder_path=sub_folder_path,
             )
-            sub_folder.parent = self
+            # sub_folder.parent = self
 
             self.add_child_component(component=sub_folder)
 
